@@ -162,30 +162,17 @@ class Problem(u.Canonical):
         dict
             The dimensions of the cones.
         """
+        # Initialize dimensions.
         dims = {}
-        dims["f"] = sum(c.size[0]*c.size[1] for c in constr_map[s.EQ])
-        dims["l"] = sum(c.size[0]*c.size[1] for c in constr_map[s.LEQ])
-        # Formats SOC, SOC_EW, and SDP constraints for the solver.
-        nonlin = constr_map[s.SOC] + constr_map[s.SDP]
+        dims[s.EQ_DIM] = sum(c.size[0]*c.size[1] for c in constr_map[s.EQ])
+        dims[s.LEQ_DIM] = sum(c.size[0]*c.size[1] for c in constr_map[s.LEQ])
+        dims[s.SOC_DIM] = []
+        dims[s.SDP_DIM] = []
+        dims[s.EXP_DIM] = 0
+        # Formats SOC, SOC_EW, SDP, and EXP constraints for the solver.
+        nonlin = constr_map[s.SOC] + constr_map[s.SDP] + constr_map[s.EXP]
         for constr in nonlin:
-            for ineq_constr in constr.format():
-                constr_map[s.LEQ].append(ineq_constr)
-        # Elemwise SOC constraints have an SOC constraint
-        # for each element in their arguments.
-        dims["q"] = []
-        for constr in constr_map[s.SOC]:
-            for cone_size in constr.size:
-                dims["q"].append(cone_size[0])
-        dims["s"] = [c.size[0] for c in constr_map[s.SDP]]
-
-        # Format exponential cone constraints.
-        if solver == s.CVXOPT:
-            for constr in constr_map[s.EXP]:
-                constr_map[s.EQ] += constr.format(s.CVXOPT)
-        elif solver == s.SCS:
-            for constr in constr_map[s.EXP]:
-                constr_map[s.LEQ] += constr.format(s.SCS)
-            dims["ep"] = sum(c.size[0]*c.size[1] for c in constr_map[s.EXP])
+            constr.format(constr_map[s.EQ], constr_map[s.LEQ], dims, solver)
 
         return dims
 
@@ -230,7 +217,7 @@ class Problem(u.Canonical):
         """
         if (constr_map[s.SDP] and not solver in s.SDP_CAPABLE) or \
            (constr_map[s.EXP] and not solver in s.EXP_CAPABLE) or \
-           (self._constraints_count(constr_map) == 0 and solver != s.ECOS):
+           (self._constraints_count(constr_map) == 0 and solver == s.SCS):
             raise Exception(
                 "The solver %s cannot solve the problem." % solver
             )
